import pipes
import yaml
from yaml.loader import SafeLoader
from yaml.reader import ReaderError

def get_orange_pipelines():
	with open('./orange.yml') as orange:
		data = yaml.load(orange, Loader=SafeLoader)
	if (data == None):
		raise ReaderError('"orange.yml" is empty')
	return data.get('pipelines')

def get_envs(pipeline: str):
	pipelines = get_orange_pipelines()
	pipes = pipelines.get(pipeline)
	if (pipes == None):
		print('Fails to read environment variables from "',pipeline,'" pipeline into orange.yml')
		raise ReaderError('Fails to read environment variables from pipeline into orange.yml')
	envs = pipes.get('env')
	if (envs == None):
		print('The "',pipeline,'" env field is empty')	
		raise ReaderError('The pipeline env field is empty')
	return envs

def apply_orange_envs(pipeline: str):
	envs = get_envs(pipeline)
	for env in envs:
		envs_value = pipes.quote(str(envs.get(env)))
		print('export %s=%s' % (env, envs_value))



import pipeline
from argparse import ArgumentParser

parser = ArgumentParser()
parser.add_argument("-p", "--pipeline", dest="pipeline",
                    help="enter the pipeline name")

args = vars(parser.parse_args())

if (args['pipeline'] == None):
	raise RuntimeError('you must pass the pipeline name')

def apply_orange_envs():
	pipeline.apply_orange_envs(args['pipeline'])



from setuptools import find_packages, setup

setup(
	name='orangepipes',
	packages=find_packages(include=['orangepipes']),
	version='0.1.4',
	description='Python library to read an orange.yml file and write the variables to the system.',
	long_description=open('README.md').read(),
	long_description_content_type = 'text/markdown',
	url='',
	license='MIT',
	install_requires=['pyyaml==5.4.1']
)